@@ -1081,8 +1081,10 @@ ins_igsl (khash_t (igsl) * hash, uint32_t key, uint32_t value) {
   }
 
   k = kh_put (igsl, hash, key, &ret);
-  if (ret == -1)
+  if (ret == -1) {
+    list_remove_nodes (list);
     return -1;
+  }
 
   kh_val (hash, k) = list;
 
@@ -1753,6 +1755,7 @@ restore_dates (void) {
   char *path = NULL;
   uint32_t date, idx = 0;
   char fmt[] = "A(u)";
+  int len;
 
   if (!(path = check_restore_path ("I32_DATES.db")))
     return;
@@ -1760,7 +1763,10 @@ restore_dates (void) {
   tn = tpl_map (fmt, &date);
   tpl_load (tn, TPL_FILE, path);
 
-  persisted_dates_len = tpl_Alen (tn, 1);
+  len = tpl_Alen (tn, 1);
+  if (len < 0)
+    return;
+  persisted_dates_len = len;
   persisted_dates = xcalloc (persisted_dates_len, sizeof (uint32_t));
   while (tpl_unpack (tn, 1) > 0)
     persisted_dates[idx++] = date;
