@@ -768,11 +768,29 @@ parse_tail_follow (GLog * glog, FILE * fp) {
   }
 }
 
+static void
+verify_inode (FILE * fp, GLog * glog) {
+  struct stat fdstat;
+
+  if (stat (glog->filename, &fdstat) == -1)
+    FATAL ("Unable to stat the specified log file '%s'. %s", glog->filename, strerror (errno));
+
+  glog->size = fdstat.st_size;
+  /* Either the log got smaller, probably was truncated so start reading from 0
+   * and reset snippet.
+   * If the log changed its inode, more likely the log was rotated, so we set
+   * the initial snippet for the new log for future iterations */
+  if (fdstat.st_ino != glog->inode || glog->snippet[0] == '\0' || 0 == glog->size) {
+    glog->length = glog->bytes = 0;
+    set_initial_persisted_data (glog, fp, glog->filename);
+  }
+  glog->inode = fdstat.st_ino;
+}
+
 /* Process appended log data */
 static void
 perform_tail_follow (GLog * glog) {
   FILE *fp = NULL;
-  struct stat fdstat;
   char buf[READ_BYTES + 1] = { 0 };
   uint16_t len = 0;
   uint64_t length = 0;
@@ -796,20 +814,15 @@ perform_tail_follow (GLog * glog) {
   if (!(fp = fopen (glog->filename, "r")))
     FATAL ("Unable to read the specified log file '%s'. %s", glog->filename, strerror (errno));
 
-  /* insert the inode of the file parsed and the last line parsed */
-  if (stat (glog->filename, &fdstat) == 0) {
-    glog->inode = fdstat.st_ino;
-    glog->size = fdstat.st_size;
-  }
+  verify_inode (fp, glog);
 
   len = MIN (glog->snippetlen, length);
-  /* This is not ideal, but maybe the only way reliable way to know if the
+  /* This is not ideal, but maybe the only reliable way to know if the
    * current log looks different than our first read/parse */
   if ((fread (buf, len, 1, fp)) != 1 && ferror (fp))
     FATAL ("Unable to fread the specified log file '%s'", glog->filename);
 
-  /* Either the log got smaller, probably was truncated so start reading from 0.
-   * For the case where the log got larger since the last iteration, we attempt
+  /* For the case where the log got larger since the last iteration, we attempt
    * to compare the first READ_BYTES against the READ_BYTES we had since the last
    * parse. If it's different, then it means the file may got truncated but grew
    * faster than the last iteration (odd, but possible), so we read from 0* */
@@ -825,24 +838,25 @@ perform_tail_follow (GLog * glog) {
   /* insert the inode of the file parsed and the last line parsed */
   if (glog->inode) {
     glog->lp.line = glog->read;
-    glog->lp.size = fdstat.st_size;
+    glog->lp.size = glog->size;
     ht_insert_last_parse (glog->inode, glog->lp);
   }
 
 out:
 
-  if (!conf.output_stdout)
+  if (!conf.output_stdout) {
     tail_term ();
-  else
+    usleep (200000);    /* 0.2 seconds */
+  } else {
     tail_html ();
-
-  usleep (200000);      /* 0.2 seconds */
+  }
 }
 
 /* Entry point to start processing the HTML output */
 static void
 process_html (const char *filename) {
   int i = 0;
+  uint64_t intval = conf.html_refresh ? conf.html_refresh : HTML_REFRESH;
 
   /* render report */
   pthread_mutex_lock (&gdns_thread.mutex);
@@ -870,7 +884,7 @@ process_html (const char *filename) {
 
     for (i = 0; i < logs->size; ++i)
       perform_tail_follow (&logs->glog[i]);     /* 0.2 secs */
-    usleep (800000);    /* 0.8 secs */
+    usleep (intval);    /* 0.8 secs */
   }
   close (gwswriter->fd);
 }
@@ -1362,8 +1376,9 @@ initializer (void) {
 static char *
 generate_fifo_name (void) {
   char fname[RAND_FN];
-  const char *tmp = NULL;
-  char *path = NULL;
+  const char *tmp;
+  char *path;
+  size_t len;
 
   if ((tmp = getenv ("TMPDIR")) == NULL)
     tmp = "/tmp";
@@ -1371,8 +1386,9 @@ generate_fifo_name (void) {
   memset (fname, 0, sizeof (fname));
   genstr (fname, RAND_FN - 1);
 
-  path = xmalloc (snprintf (NULL, 0, "%s/goaccess_fifo_%s", tmp, fname) + 1);
-  sprintf (path, "%s/goaccess_fifo_%s", tmp, fname);
+  len = snprintf (NULL, 0, "%s/goaccess_fifo_%s", tmp, fname) + 1;
+  path = xmalloc (len);
+  snprintf (path, len, "%s/goaccess_fifo_%s", tmp, fname);
 
   return path;
 }
