@@ -532,6 +532,8 @@ init_log_item (GLog * glog) {
   /* UMS */
   logitem->mime_type = NULL;
   logitem->tls_type = NULL;
+  logitem->tls_cypher = NULL;
+  logitem->tls_type_cypher = NULL;
 
   memset (logitem->site, 0, sizeof (logitem->site));
   localtime_r (&now, &logitem->dt);
@@ -593,6 +595,10 @@ free_glog (GLogItem * logitem) {
     free (logitem->mime_type);
   if (logitem->tls_type != NULL)
     free (logitem->tls_type);
+  if (logitem->tls_cypher != NULL)
+    free (logitem->tls_cypher);
+  if (logitem->tls_type_cypher != NULL)
+    free (logitem->tls_type_cypher);
 
   free (logitem);
 }
@@ -683,8 +689,10 @@ extract_keyphrase (char *ref, char **keyphrase) {
     *ptr = '\0';
 
   referer = decode_url (r);
-  if (referer == NULL || *referer == '\0')
+  if (referer == NULL || *referer == '\0') {
+    free (referer);
     return 1;
+  }
 
   referer = char_replace (referer, '+', ' ');
   *keyphrase = trim_str (referer);
@@ -1227,8 +1235,10 @@ parse_specifier (GLogItem * logitem, char **str, const char *p, const char *end)
     if (logitem->req)
       return spec_err (logitem, SPEC_TOKN_SET, *p, NULL);
     tkn = parse_string (&(*str), end, 1);
-    if (tkn == NULL || *tkn == '\0')
+    if (tkn == NULL || *tkn == '\0') {
+      free (tkn);
       return spec_err (logitem, SPEC_TOKN_NUL, *p, NULL);
+    }
 
     if ((logitem->req = decode_url (tkn)) == NULL) {
       spec_err (logitem, SPEC_TOKN_INV, *p, tkn);
@@ -1242,8 +1252,10 @@ parse_specifier (GLogItem * logitem, char **str, const char *p, const char *end)
     if (logitem->qstr)
       return spec_err (logitem, SPEC_TOKN_SET, *p, NULL);
     tkn = parse_string (&(*str), end, 1);
-    if (tkn == NULL || *tkn == '\0')
+    if (tkn == NULL || *tkn == '\0') {
+      free (tkn);
       return 0;
+    }
 
     if ((logitem->qstr = decode_url (tkn)) == NULL) {
       spec_err (logitem, SPEC_TOKN_INV, *p, tkn);
@@ -1409,17 +1421,28 @@ parse_specifier (GLogItem * logitem, char **str, const char *p, const char *end)
     free (tkn);
     break;
 
-    /* UMS: Krypto (TLS) parameters like "TLSv1.2 ECDHE-RSA-AES128-GCM-SHA256" */
+    /* UMS: Krypto (TLS) "ECDHE-RSA-AES128-GCM-SHA256" */
+  case 'k':
+    /* error to set this twice */
+    if (logitem->tls_cypher)
+      return spec_err (logitem, SPEC_TOKN_SET, *p, NULL);
+
+    if (!(tkn = parse_string (&(*str), end, 1)))
+      return spec_err (logitem, SPEC_TOKN_NUL, *p, NULL);
+
+    logitem->tls_cypher = tkn;
+    break;
+
+    /* UMS: Krypto (TLS) parameters like "TLSv1.2" */
   case 'K':
     /* error to set this twice */
     if (logitem->tls_type)
       return spec_err (logitem, SPEC_TOKN_SET, *p, NULL);
 
-    if (!(tkn = parse_string (&(*str), end, 2)))
+    if (!(tkn = parse_string (&(*str), end, 1)))
       return spec_err (logitem, SPEC_TOKN_NUL, *p, NULL);
 
     logitem->tls_type = tkn;
-
     break;
 
     /* UMS: Mime-Type like "text/html" */
@@ -2147,7 +2170,10 @@ gen_visitor_key (GKeyData * kdata, GLogItem * logitem) {
  */
 static int
 gen_req_key (GKeyData * kdata, GLogItem * logitem) {
-  if (logitem->req && logitem->qstr)
+  if (!logitem->req)
+    return 1;
+
+  if (logitem->qstr)
     append_query_string (&logitem->req, logitem->qstr);
   logitem->req_key = gen_unique_req_key (logitem);
 
@@ -2385,12 +2411,12 @@ static const char *
 extract_tlsmajor (const char *token) {
   const char *lookfor;
 
-  if ((lookfor = "SSLv3", strstr (token, lookfor)) ||
-      (lookfor = "TLSv1.1", strstr (token, lookfor)) ||
-      (lookfor = "TLSv1.2", strstr (token, lookfor)) ||
-      (lookfor = "TLSv1.3", strstr (token, lookfor)) ||
-      // Nope, it's not 1.0
-      (lookfor = "TLSv1", strstr (token, lookfor)))
+  if ((lookfor = "SSLv3", !strncmp (token, lookfor, 5)) ||
+      (lookfor = "TLSv1.1", !strncmp (token, lookfor, 7)) ||
+      (lookfor = "TLSv1.2", !strncmp (token, lookfor, 7)) ||
+      (lookfor = "TLSv1.3", !strncmp (token, lookfor, 7)) ||
+      /* Nope, it's not 1.0 */
+      (lookfor = "TLSv1", !strncmp (token, lookfor, 5)))
     return lookfor;
   return NULL;
 }
@@ -2403,6 +2429,7 @@ extract_tlsmajor (const char *token) {
 static int
 gen_tls_type_key (GKeyData * kdata, GLogItem * logitem) {
   const char *tls;
+  size_t tlen = 0, clen = 0;
 
   if (!logitem->tls_type)
     return 1;
@@ -2413,9 +2440,23 @@ gen_tls_type_key (GKeyData * kdata, GLogItem * logitem) {
   if (!tls)
     return 1;
 
-  kdata->data = logitem->tls_type;
-  kdata->data_key = logitem->tls_type;
   kdata->numdate = logitem->numdate;
+  if (!logitem->tls_cypher) {
+    kdata->data_key = kdata->data = kdata->root = kdata->root_key = tls;
+    return 0;
+  }
+
+  clen = strlen (logitem->tls_cypher);
+  tlen = strlen (tls);
+
+  logitem->tls_type_cypher = xmalloc (tlen + clen + 2);
+  memcpy (logitem->tls_type_cypher, tls, tlen);
+  logitem->tls_type_cypher[tlen] = '/';
+  /* includes terminating null */
+  memcpy (logitem->tls_type_cypher + tlen + 1, logitem->tls_cypher, clen + 1);
+
+  kdata->data = logitem->tls_type_cypher;
+  kdata->data_key = logitem->tls_type_cypher;
 
   kdata->root = tls;
   kdata->root_key = tls;
@@ -2611,7 +2652,7 @@ set_datamap (GLogItem * logitem, GKeyData * kdata, const GParse * parse) {
   parse->datamap (module, kdata);
 
   /* insert rootmap and root-data map */
-  if (parse->rootmap) {
+  if (parse->rootmap && kdata->root) {
     parse->rootmap (module, kdata);
     insert_root (module, kdata);
   }
@@ -2761,16 +2802,16 @@ process_log (GLogItem * logitem) {
  * Returns 1 if the content is likely the same or no data to compare
  * Returns 0 if it has different content */
 static int
-is_likely_same_log (GLog * glog, GLastParse lp) {
+is_likely_same_log (GLog * glog, const GLastParse * lp) {
   size_t size = 0;
 
-  if (!lp.size)
+  if (!lp->size)
     return 1;
 
   /* Must be a LOG */
-  size = MIN (glog->snippetlen, lp.snippetlen);
-  if (glog->snippet[0] != '\0' && lp.snippet[0] != '\0' &&
-      memcmp (glog->snippet, lp.snippet, size) == 0)
+  size = MIN (glog->snippetlen, lp->snippetlen);
+  if (glog->snippet[0] != '\0' && lp->snippet[0] != '\0' &&
+      memcmp (glog->snippet, lp->snippet, size) == 0)
     return 1;
 
   return 0;
@@ -2797,7 +2838,7 @@ should_restore_from_disk (GLog * glog) {
 
   /* If our current line is greater or equal (zero indexed) to the last parsed
    * line and have equal timestamps, then keep parsing then */
-  if (glog->inode && is_likely_same_log (glog, lp)) {
+  if (glog->inode && is_likely_same_log (glog, &lp)) {
     if (glog->size > lp.size && glog->read >= lp.line)
       return 0;
     return 1;
@@ -2842,7 +2883,7 @@ process_invalid (GLog * glog, GLogItem * logitem, const char *line) {
 
   /* If our current line is greater or equal (zero indexed) to the last parsed
    * line then keep parsing then */
-  if (glog->inode && is_likely_same_log (glog, lp)) {
+  if (glog->inode && is_likely_same_log (glog, &lp)) {
     /* only count invalids if we're past the last parsed line */
     if (glog->size > lp.size && glog->read >= lp.line)
       count_process_and_invalid (glog, line);
@@ -3075,10 +3116,14 @@ read_lines (FILE * fp, GLog * glog, int dry_run) {
  *
  * On error, 1 is returned.
  * On success, 0 is returned. */
-static int
+int
 set_initial_persisted_data (GLog * glog, FILE * fp, const char *fn) {
   size_t len;
 
+  /* reset the snippet */
+  memset (glog->snippet, 0, sizeof (glog->snippet));
+  glog->snippetlen = 0;
+
   if (glog->size == 0)
     return 1;
 
