@@ -91,6 +91,8 @@ typedef struct GLogItem_ {
   /* UMS */
   char *mime_type;
   char *tls_type;
+  char *tls_cypher;
+  char *tls_type_cypher;
 
   char *errstr;
   struct tm dt;
@@ -110,7 +112,7 @@ typedef struct GLog_ {
   uint8_t log_erridx;
   uint32_t read;                /* lines read/parsed */
   uint32_t inode;               /* inode of the log */
-  uint64_t bytes;               /* bytes read */
+  uint64_t bytes;               /* bytes read on each iteration */
   uint64_t size;                /* original size of log */
   uint64_t length;              /* length read from the log so far */
   uint64_t invalid;             /* invalid lines for this log */
@@ -205,6 +207,7 @@ char *fgetline (FILE * fp);
 char **test_format (Logs * logs, int *len);
 int parse_log (Logs * logs, int dry_run);
 int pre_process_log (GLog * glog, char *line, int dry_run);
+int set_initial_persisted_data (GLog * glog, FILE * fp, const char *fn);
 void free_logerrors (GLog * glog);
 void free_logs (Logs * logs);
 void free_raw_data (GRawData * raw_data);
