@@ -1224,7 +1224,7 @@ send_buffer (WSClient * client, const char *buffer, int len) {
 #endif
 }
 
-/* Attmpt to send the given buffer to the given socket.
+/* Attempt to send the given buffer to the given socket.
  *
  * On error, -1 is returned and the connection status is set.
  * On success, the number of bytes sent is returned. */
@@ -1473,7 +1473,7 @@ ws_set_handshake_headers (WSHeaders * headers) {
   if (!headers->upgrade)
     headers->upgrade = xstrdup ("websocket");
   if (!headers->connection)
-    headers->upgrade = xstrdup ("Upgrade");
+    headers->connection = xstrdup ("Upgrade");
 
   free (s);
 }
@@ -1904,7 +1904,7 @@ ws_set_masking_key (WSFrame * frm, const char *buf) {
   }
 }
 
-/* Attempt to read the frame's header and set the relavant data into
+/* Attempt to read the frame's header and set the relevant data into
  * our frame structure.
  *
  * On error, or if no data available to read, the number of bytes is
@@ -1993,7 +1993,7 @@ ws_realloc_frm_payload (WSFrame * frm, WSMessage * msg) {
   return 0;
 }
 
-/* Attempt to read the frame's payload and set the relavant data into
+/* Attempt to read the frame's payload and set the relevant data into
  * our message structure.
  *
  * On error, or if no data available to read, the number of bytes is
@@ -2125,7 +2125,9 @@ handle_accept (int listener, WSServer * server) {
   if (newfd == -1)
     return;
 
-  client = ws_get_client_from_list (newfd, &server->colist);
+  if (!(client = ws_get_client_from_list (newfd, &server->colist)))
+    return;
+
   if (newfd > FD_SETSIZE - 1) {
     LOG (("Too busy: %d %s.\n", newfd, client->remote_ip));
 
@@ -2160,7 +2162,7 @@ handle_reads (int conn, WSServer * server) {
   /* *INDENT-ON* */
   gettimeofday (&client->start_proc, NULL);
   read_client_data (client, server);
-  /* An error ocurred while reading data or connection closed */
+  /* An error occurred while reading data or connection closed */
   if ((client->status & WS_CLOSE)) {
     handle_read_close (conn, client, server);
   }
@@ -2190,7 +2192,7 @@ handle_writes (int conn, WSServer * server) {
   if (client->sockqueue == NULL)
     client->status &= ~WS_SENDING;
 
-  /* An error ocurred while sending data or while reading data but still
+  /* An error occurred while sending data or while reading data but still
    * waiting from the last send() from the server to the client.  e.g.,
    * sending status code */
   if ((client->status & WS_CLOSE) && !(client->status & WS_SENDING))
@@ -2234,14 +2236,12 @@ ws_setfifo (const char *pipename) {
 }
 
 /* Open a named pipe (FIFO) for input to the server (reader). */
-static int
+static void
 ws_openfifo_in (WSPipeIn * pipein) {
   ws_setfifo (wsconfig.pipein);
   /* we should be able to open it at as reader */
   if ((pipein->fd = open (wsconfig.pipein, O_RDWR | O_NONBLOCK)) < 0)
     FATAL ("Unable to open fifo in: %s.", strerror (errno));
-
-  return pipein->fd;
 }
 
 
@@ -2334,7 +2334,7 @@ ws_queue_fifobuf (WSPipeOut * pipeout, const char *buffer, int len, int bytes) {
   pipeout->status |= WS_SENDING;
 }
 
-/* Attmpt to send the given buffer to the given outgoing FIFO.
+/* Attempt to send the given buffer to the given outgoing FIFO.
  *
  * On error, the data is queued up.
  * On success, the number of bytes sent is returned. */
@@ -2583,7 +2583,7 @@ handle_strict_fifo (WSServer * server) {
     return;
   }
 
-  /* Either send it to a specific client or brodcast message to all
+  /* Either send it to a specific client or broadcast message to all
    * clients */
   if (listener != 0)
     ws_send_strict_fifo_to_client (server, listener, *pa);
@@ -2602,7 +2602,7 @@ handle_fixed_fifo (WSServer * server) {
   int bytes = 0;
   char buf[PIPE_BUF] = { 0 };
 
-  if ((bytes = read (pi->fd, buf, PIPE_BUF)) < 0)
+  if ((bytes = read (pi->fd, buf, PIPE_BUF - 1)) < 0)
     return;
 
   buf[bytes] = '\0';    /* null-terminate */
@@ -2620,7 +2620,7 @@ handle_fixed_fifo (WSServer * server) {
     return;
   }
 
-  /* brodcast message to all clients */
+  /* broadcast message to all clients */
   list_foreach (server->colist, ws_broadcast_fifo, *pa);
   clear_fifo_packet (pi);
 }
@@ -2650,7 +2650,8 @@ ws_socket (int *listener) {
     FATAL ("Unable to set server: %s.", gai_strerror (errno));
 
   /* Create a TCP socket.  */
-  *listener = socket (ai->ai_family, ai->ai_socktype, ai->ai_protocol);
+  if ((*listener = socket (ai->ai_family, ai->ai_socktype, ai->ai_protocol)) == -1)
+    FATAL ("Unable to open socket: %s.", strerror (errno));
 
   /* Options */
   if (setsockopt (*listener, SOL_SOCKET, SO_REUSEADDR, &ov, sizeof (ov)) == -1)
